@@ -24,6 +24,8 @@ import unittest
 from fedmsg.tests.test_meta import Base
 
 from fedmsg_meta_fedora_infrastructure.tests.pkgdb import *
+from fedmsg_meta_fedora_infrastructure.tests.planet import *
+from fedmsg_meta_fedora_infrastructure.tests.buildsys import *
 
 
 class TestFASUserCreate(Base):
